AgentSignUpScreen class

Inheritance

Constructors

AgentSignUpScreen({Key? key, List<int> fixedLengthList = const [], List<File> fixedFileList = const [], required dynamic apiController, required dynamic onTapLocation(), required dynamic onTapPrivacy(), dynamic maskTextInputFormatter, dynamic userDetails, String agentInfo = 'lang_agent_info', String nameLabel = 'lang_name', String thisFieldRequired = 'lang_this_field', String lastNameLabel = 'lang_last_name', String placeNameLabel = 'lang_place_name', String placeAddressLabel = 'lang_place_address', String addPhotosLabel = 'lang_add_photos', String nextButtonLabel = 'lang_next', String iAgreeToLabel = 'lang_i_agree_to', String privacyPolicyLabel = 'lang_privacy_policy', String isCheckedError = 'lang_isChecked', String mobileNumberLabel = 'lang_mobile_number', String enterValidEmailError = 'lang_enter_valid_email', String emailLabel = 'lang_email', dynamic contextLocale, dynamic formKey, dynamic placeAddressController, required Future<void> onNextParess(dynamic number, dynamic name, dynamic lastName, dynamic email, dynamic placeName, dynamic placeAddress)})
const

Properties

addPhotosLabel String
final
agentInfo String
final
apiController → dynamic
final
contextLocale → dynamic
final
emailLabel String
final
enterValidEmailError String
final
fixedFileList List<File>
final
fixedLengthList List<int>
final
formKey → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
iAgreeToLabel String
final
isCheckedError String
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastNameLabel String
final
maskTextInputFormatter → dynamic
final
mobileNumberLabel String
final
nameLabel String
final
nextButtonLabel String
final
onNextParess Future<void> Function(dynamic number, dynamic name, dynamic lastName, dynamic email, dynamic placeName, dynamic placeAddress)
final
onTapLocation → dynamic Function()
final
onTapPrivacy → dynamic Function()
final
placeAddressController → dynamic
final
placeAddressLabel String
final
placeNameLabel String
final
privacyPolicyLabel String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thisFieldRequired String
final
userDetails → dynamic
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _AgentSignUpScreenState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited