CustomerSignUpScreenState class

Inheritance

Constructors

CustomerSignUpScreenState()

Properties

context BuildContext
The location in the tree where this widget builds.
no setterinherited
emailController TextEditingController
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastNameController TextEditingController
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
nameController TextEditingController
getter/setter pair
passwordController TextEditingController
getter/setter pair
phoneNumberController TextEditingController
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widget CustomerSignUpScreen
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
buildCheckboxListTileFormField(BuildContext context) Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant CustomerSignUpScreen oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
fixedEmailField(String validator) TextFormField
fixedPhoneNumberField() TextFormField
fixedTextField(String title, TextEditingController controller, String validator, dynamic keyName) TextFormField
fixedTitle(BuildContext context) Widget
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited