DriverTransportPage class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DriverTransportPage
Constructors
-
DriverTransportPage({Key? key, dynamic apiController, dynamic driverInfo, required Future<
void> onPressNext(dynamic dInfo, dynamic imageIds), String lang_transport = 'lang_transport', String lang_next = 'lang_next', String lang_transport_info_text = 'lang_transport_info_text', String lang_tr_front_view = 'lang_tr_front_view', String lang_tr_rear_view = 'lang_tr_rear_view'}) -
const
Properties
- apiController → dynamic
-
final
- driverInfo → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lang_next → String
-
final
- lang_tr_front_view → String
-
final
- lang_tr_rear_view → String
-
final
- lang_transport → String
-
final
- lang_transport_info_text → String
-
final
-
onPressNext
→ Future<
void> Function(dynamic dInfo, dynamic imageIds) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _DriverTransportPageState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited