CustomerSignUpScreen class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomerSignUpScreen
Constructors
-
CustomerSignUpScreen({Key? key, bool? checkbox, int platform = 3, dynamic apiController, dynamic maskTextInputFormatter, Key nameKey = const Key("name"), Key lastName = const Key("lastName"), dynamic formKey, dynamic user, dynamic settingsArguments, required String langEmailIncorrect, required String langName, required String langRequired, required String langLastName, required String langNext, required String langIAgreeTo, required String langPrivacyPolicy, required String langEmail, required String langMobileNumber, required String langSignUp, required Future<
void> onPressedNext(dynamic number, dynamic email, dynamic name, dynamic lastName), required void pop(), dynamic contextLocale, bool phoneNumberUnabled = false}) -
const
Properties
- apiController → dynamic
-
final
- checkbox → bool?
-
final
- contextLocale → dynamic
-
final
- formKey → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- langEmail → String
-
final
- langEmailIncorrect → String
-
final
- langIAgreeTo → String
-
final
- langLastName → String
-
final
- langMobileNumber → String
-
final
- langName → String
-
final
- langNext → String
-
final
- langPrivacyPolicy → String
-
final
- langRequired → String
-
final
- langSignUp → String
-
final
- lastName → Key
-
final
- maskTextInputFormatter → dynamic
-
final
- nameKey → Key
-
final
-
onPressedNext
→ Future<
void> Function(dynamic number, dynamic email, dynamic name, dynamic lastName) -
final
- phoneNumberUnabled → bool
-
final
- platform → int
-
final
- pop → void Function()
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingsArguments → dynamic
-
final
- user → dynamic
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → CustomerSignUpScreenState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited